.. ident_parsers:

.. default-domain:: py

Ident parsers
=============

X!Tandem alanine
****************

.. autoclass:: unify_idents.engine_parsers.xtandem_alanine.XTandemAlanine
    :members:
    :show-inheritance:
    :member-order: bysource

    .. automethod:: _unify_row
    .. automethod:: __iter__
    .. automethod:: _next


MSFragger
*********

.. autoclass:: unify_idents.engine_parsers.msfragger3_parser.MSFragger3Parser
    :members:
    :show-inheritance:
    :member-order: bysource

    .. automethod:: _unify_row
    .. automethod:: __next__


Omssa
*****

.. autoclass:: unify_idents.engine_parsers.omssa_parser.OmssaParser
    :members:
    :show-inheritance:
    :member-order: bysource

    .. automethod:: _unify_row
    .. automethod:: __next__


MSGF+ (2021.03.22)
******************

.. autoclass:: unify_idents.engine_parsers.msgfplus_2021_03_22_parser.MSGFPlus_2021_03_22
    :members:
    :show-inheritance:
    :member-order: bysource

    .. automethod:: _unify_row
    .. automethod:: __iter__
    .. automethod:: _next


MSamanda
********

.. autoclass:: unify_idents.engine_parsers.msamanda_parser.MSamandaParser
    :members:
    :show-inheritance:
    :member-order: bysource

    .. automethod:: _unify_row
    .. automethod:: __next__